@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2010 Piotr Eljasiak
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,6 @@
 
 typedef struct _GnomeCmdFileInfo        GnomeCmdFileInfo;
 typedef struct _GnomeCmdFileInfoClass   GnomeCmdFileInfoClass;
-typedef struct _GnomeCmdFileInfoPrivate GnomeCmdFileInfoPrivate;
 
 struct _GnomeCmdFileInfo
 {
@@ -36,8 +35,6 @@ struct _GnomeCmdFileInfo
 
     GnomeVFSURI *uri;
     GnomeVFSFileInfo *info;
-
-    GnomeCmdFileInfoPrivate *priv;
 };
 
 struct _GnomeCmdFileInfoClass
