@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2009 Piotr Eljasiak
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -21,8 +21,6 @@
 #ifndef __LIBGCMD_DATA_H__
 #define __LIBGCMD_DATA_H__
 
-G_BEGIN_DECLS
-
 void gnome_cmd_data_set_string (const gchar *path, const gchar *value);
 
 void gnome_cmd_data_set_int (const gchar *path, int value);
@@ -39,6 +37,4 @@ gboolean gnome_cmd_data_get_bool (const gchar *path, gboolean def);
 
 void gnome_cmd_data_get_color (const gchar *path, GdkColor *color);
 
-G_END_DECLS
-
 #endif //__LIBGCMD_DATA_H__
