@@ -1,7 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
-    Copyright (C) 2007-2010 Piotr Eljasiak
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -53,18 +53,9 @@ extern struct lconv *locale_information;
 #define STRINGS_TO_URIS_CHUNK 1024
 
 static GdkCursor *cursor_busy = NULL;
-extern gchar *debug_flags;
 static gchar *tmp_file_dir = NULL;
 
 
-gboolean DEBUG_ENABLED (gchar flag)
-{
-    if (debug_flags != NULL)
-       return strchr(debug_flags, flag) != 0;
-
-    return FALSE;
-}
-
 /**
  * The already reserved debug flags:
  * --------------------------------
@@ -1181,7 +1172,7 @@ gchar *unc_to_unix (const gchar *path)
 GdkColor *gdk_color_new (gushort r, gushort g, gushort b)
 {
     GdkColor *c = g_new0 (GdkColor, 1);
-    c->pixel = 0;
+    // c->pixel = 0;
     c->red = r;
     c->green = g;
     c->blue = b;
@@ -1355,7 +1346,7 @@ void gnome_cmd_toggle_file_name_selection (GtkWidget *entry)
     {
         glong text_len = g_utf8_strlen (text, -1);
 
-        s = strrchr(text,'.');                                      // '.' is ASCII, g_utf8_strrchr() is not needed here
+        s = strrchr(s ? s : text,'.');                                      // '.' is ASCII, g_utf8_strrchr() is not needed here
         glong ext = s ? g_utf8_pointer_to_offset (text, s) : -1;
 
         if (beg==0 && end==text_len)
